@@ -49,31 +49,48 @@ def print_speaker_info(speaker):
 
 def play_sonos_favourite(speaker, favourite):
     fs = speaker.music_library.get_sonos_favorites()
+    the_fav = None
+    # Strict match (case insensitive)
     for f in fs:
-        # Loose match
-        if favourite.lower() in f.title.lower():
-            uri = f.get_uri()
-            metadata = f.resource_meta_data
-            # play_uri works for some favourites
-            try:
-                speaker.play_uri(uri=uri, meta=metadata)
-                return
-            except Exception as e:
-                # error_and_exit(str(e))
-                e1 = e
-                pass
-            # Other favourites have to be added to the queue, then played
-            try:
-                speaker.clear_queue()
-                index = speaker.add_to_queue(f)
-                speaker.play_from_queue(index=0, start=True)
-                return
-            except Exception as e2:
-                error_and_exit("{}, {}".format(str(e1), str(e2)))
-                return
+        if favourite.lower() == f.title.lower():
+            the_fav = f
+    # Loose substring match if strict match not available
+    if not the_fav:
+        for f in fs:
+            if favourite.lower() in f.title.lower():
+                the_fav = f
+    if the_fav:
+        # play_uri works for some favourites
+        try:
+            uri = the_fav.get_uri()
+            metadata = the_fav.resource_meta_data
+            speaker.play_uri(uri=uri, meta=metadata)
+            return  # Success
+        except Exception as e:
+            e1 = e
+            pass
+        # Other favourites have to be added to the queue, then played
+        try:
+            speaker.clear_queue()
+            index = speaker.add_to_queue(the_fav)
+            speaker.play_from_queue(index=0, start=True)
+            return
+        except Exception as e2:
+            error_and_exit("{}, {}".format(str(e1), str(e2)))
+            return
     error_and_exit("Favourite '{}' not found".format(favourite))
 
 
+def list_favourites(speaker):
+    fs = speaker.music_library.get_sonos_favorites()
+    favs = []
+    for f in fs:
+        favs.append(f.title)
+    favs.sort()
+    for f in favs:
+        print(f)
+
+
 def pause_all(speaker):
     zones = speaker.all_zones
     for zone in zones:
@@ -86,6 +103,18 @@ def pause_all(speaker):
                 pass
 
 
+def ungroup_all(speaker):
+    zones = speaker.all_zones
+    for zone in zones:
+        if zone.is_visible:
+            try:
+                zone.unjoin()
+            except:
+                # Ignore errors here; don't want to halt on
+                # a failed pause (e.g., if speaker isn't playing)
+                pass
+
+
 def get_speaker(name, local=False):
     if local:
         return speaker_list.find(name)
@@ -377,6 +406,11 @@ def main():
                 error_and_exit("Action 'favourite/favorite/fav' requires 1 parameter")
             else:
                 play_sonos_favourite(speaker, args.parameters[0])
+        elif action in ["list_favs"]:
+            if np == 0:
+                list_favourites(speaker)
+            else:
+                error_and_exit("Action 'list_favs' requires no parameters")
         # Play URI ##################################################
         elif action in ["uri", "play_uri"]:
             if not (np == 1 or np == 2):
@@ -507,6 +541,11 @@ def main():
                         print()
             else:
                 error_and_exit("Action 'groups' requires no parameters")
+        elif action in ["ungroup_all"]:
+            if np == 0:
+                ungroup_all(speaker)
+            else:
+                error_and_exit("Action 'ungroup_all' requires no parameters")
         # Zones information #########################################
         elif action in [
             "rooms",
@@ -546,6 +585,39 @@ def main():
         elif action == "version":
             print("soco-cli version: {}".format(__version__))
             print("soco version:     {}".format(soco.__version__))
+        # Queues ####################################################
+        elif action in ["list_queue", "lq"]:
+            if np == 0:
+                queue = speaker.get_queue()
+                for i in range(len(queue)):
+                    print(
+                        "{:3d}: Artist: {} | Album: {} | Title: {}".format(
+                            i + 1, queue[i].creator, queue[i].album, queue[i].title
+                        )
+                    )
+            else:
+                error_and_exit("Action 'list_queue' requires no parameters")
+        elif action in ["play_from_queue", "pq"]:
+            if np == 1:
+                index = int(args.parameters[0])
+                speaker.play_from_queue(index - 1)
+            else:
+                error_and_exit(
+                    "Action 'play_from_queue' requires 1 (integer) parameter"
+                )
+        elif action in ["remove_from_queue", "rq"]:
+            if np == 1:
+                index = int(args.parameters[0])
+                speaker.remove_from_queue(index - 1)
+            else:
+                error_and_exit(
+                    "Action 'remove_from_queue' requires 1 (integer) parameter"
+                )
+        elif action in ["clear_queue", "cq"]:
+            if np == 0:
+                speaker.clear_queue()
+            else:
+                error_and_exit("Action 'clear_queue' requires no parameters")
         # Invalid Action ############################################
         else:
             error_and_exit("Action '{}' is not defined.".format(action))
