@@ -5,19 +5,13 @@ import socket
 import soco
 import ifaddr
 import threading
+import pprint
 from collections import namedtuple
 
 # Type for holding speaker details
 SonosDevice = namedtuple(
     "SonosDevice",
-    [
-        "household_id",
-        "ip_address",
-        "speaker_name",
-        "is_coordinator",
-        "is_visible",
-        "model_name",
-    ],
+    ["household_id", "ip_address", "speaker_name", "is_visible", "model_name",],
     rename=False,
 )
 
@@ -185,7 +179,6 @@ class Speakers:
                 speaker.household_id,
                 str(ip_addr),
                 info["zone_name"],
-                speaker.is_coordinator,
                 speaker.is_visible,
                 info["model_name"],
             )
@@ -194,17 +187,45 @@ class Speakers:
             return None
 
     @staticmethod
-    def discovery_worker(ip_list, socket_timeout, soco_timeout, sonos_devices):
+    def discovery_worker(ip_set, socket_timeout, soco_timeout, sonos_devices):
         """Worker thread to pull IP addresses from a set, test if port 1400 is open,
         and if so pull down the Sonos device data. Return when the list is empty.
         """
-        while len(ip_list) > 0:
-            ip_addr = ip_list.pop()
+        while len(ip_set) > 0:
+            ip_addr = ip_set.pop()
             if Speakers.check_ip_and_port(str(ip_addr), 1400, socket_timeout):
                 device = Speakers.get_sonos_device_data(ip_addr, soco_timeout)
                 if device:
                     sonos_devices.append(device)
 
+    def print(self):
+        if not self._speakers:
+            return
+        households = {}
+        for device in self._speakers:
+            if device.household_id not in households:
+                households[device.household_id] = []
+            if device.is_visible:
+                visible = "Visible"
+            else:
+                visible = "Hidden"
+            households[device.household_id].append(
+                (
+                    device.speaker_name,
+                    device.ip_address,
+                    device.model_name.replace("Sonos ", ""),
+                    visible,
+                )
+            )
+
+        print("{} Sonos Household(s) found: ".format(len(households)))
+        for household in households:
+            print("  {}".format(household))
+        print()
+
+        pp = pprint.PrettyPrinter(width=120)
+        pp.pprint(households)
+
     def discover(self):
         """Discover the Sonos speakers on the network(s) to which
         this host is attached."""
